//! 图书馆管理系统命令行界面

use library::{Book, User, new_library};

fn main() {
    println!("图书馆管理系统 v{}", library::VERSION);
    println!("======================");
    
    // 创建图书馆实例
    let mut library = new_library();
    
    // 添加一些示例图书
    let books = [
        Book::new("Rust编程之道", "张三", "978-1234567890"),
        Book::new("数据结构与算法", "李四", "978-2345678901"),
        Book::new("计算机网络", "王五", "978-3456789012"),
        Book::new("操作系统原理", "赵六", "978-4567890123"),
        Book::new("数据库系统概念", "钱七", "978-5678901234"),
    ];
    
    println!("\n添加图书到目录...");
    for book in &books {
        match library.catalog_mut().add_book(book.clone()) {
            Ok(_) => println!("  已添加: {}", book),
            Err(e) => println!("  添加失败: {:?}", e),
        }
    }
    
    // 添加一些用户
    let users = [
        User::new(1, "张明", "zhangming@example.com"),
        User::new(2, "李华", "lihua@example.com"),
        User::new(3, "王芳", "wangfang@example.com"),
    ];
    
    println!("\n添加用户...");
    for user in &users {
        library.lending_mut().add_user(user.clone());
        println!("  已添加: {}", user);
    }
    
    // 演示借书
    println!("\n借阅图书...");
    let borrow_examples = [
        (1, "978-1234567890"),
        (2, "978-2345678901"),
        (2, "978-3456789012"),
        (3, "978-4567890123"),
    ];
    
    for (user_id, isbn) in &borrow_examples {
        match library.borrow_book(*user_id, isbn) {
            Ok(_) => {
                let user = library.lending().find_user(*user_id as u32).unwrap();
                let book = library.catalog().find_by_isbn(isbn).unwrap();
                println!("  {} 成功借阅: {}", user.name(), book.title());
            },
            Err(e) => println!("  借阅失败: {:?}", e),
        }
    }
    
    // 显示目录状态
    println!("\n目录状态:");
    println!("  总图书数: {}", library.catalog().total_count());
    println!("  可借图书数: {}", library.catalog().available_count());
    
    // 演示查找图书
    println!("\n查找图书 (标题包含'数据'):");
    for book in library.catalog().find_by_title("数据") {
        println!("  找到: {} ({})", book.title(), if book.is_available() { "可借" } else { "已借出" });
    }
    
    // 演示归还图书
    println!("\n归还图书...");
    match library.return_book(2, "978-2345678901") {
        Ok(_) => println!("  李华成功归还《数据结构与算法》"),
        Err(e) => println!("  归还失败: {:?}", e),
    }
    
    // 再次显示目录状态
    println!("\n更新后的目录状态:");
    println!("  总图书数: {}", library.catalog().total_count());
    println!("  可借图书数: {}", library.catalog().available_count());
    
    println!("\n程序结束");
}