//! 图书馆业务服务模块

pub mod catalog;
pub mod lending;

// 不需要在这里导入，因为每个子模块都有自己的导入

/// 图书馆主服务
pub struct Library {
    catalog: catalog::Catalog,
    lending: lending::LendingService,
}

impl Library {
    /// 创建一个新的图书馆实例
    pub fn new() -> Self {
        Self {
            catalog: catalog::Catalog::new(),
            lending: lending::LendingService::new(),
        }
    }
    
    /// 获取目录服务
    pub fn catalog(&self) -> &catalog::Catalog {
        &self.catalog
    }
    
    /// 获取可变目录服务
    pub fn catalog_mut(&mut self) -> &mut catalog::Catalog {
        &mut self.catalog
    }
    
    /// 获取借阅服务
    pub fn lending(&self) -> &lending::LendingService {
        &self.lending
    }
    
    /// 获取可变借阅服务
    pub fn lending_mut(&mut self) -> &mut lending::LendingService {
        &mut self.lending
    }
    
    /// 借阅图书
    pub fn borrow_book(&mut self, user_id: usize, isbn: &str) -> Result<(), lending::LendingError> {
        self.lending.borrow_book(user_id as u32, isbn, &mut self.catalog)
    }
    
    /// 归还图书
    pub fn return_book(&mut self, user_id: usize, isbn: &str) -> Result<(), lending::LendingError> {
        self.lending.return_book(user_id as u32, isbn, &mut self.catalog)
    }
}

impl Default for Library {
    fn default() -> Self {
        Self::new()
    }
}